/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2005-2007. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/

/*
 * MarkupWIs.js - automatically mark up text matching a certain pattern as
 * hypterlinks to the corresponding work items.
 */

(function() { // closure to guard local variables

// IE doesn't know the DOM constants, so just use the literals
var ELEMENT_NODE = 1;
var TEXT_NODE    = 3;

// define the set of matching prefixes
var wiTypes = [
	"bug",
	"defect",
	"enhancement",
	"task",
	"rfs",
	"work item"
];

var regexFrag= "";
for (var i=0; i<wiTypes.length; i++) {
	regexFrag += wiTypes[i] + " " + (i<wiTypes.length-1 ? "|" : "");
}

// build up the regex
var wiMatcher    = new RegExp("((" + regexFrag + ")([0-9]+))", "gi");
var wiReplacer   = "<a href=\"/jazz/web/projects/Jazz%20Project#perspective=Work%20Items&action=viewWorkItem&id=$3\">$1</a>";

/*
 * Kicks off the recursive search for work item strings.
 */
startMarkupWIs= function() {
	markupWIs(document.body);
}

/*
 * Walks the children of the specified node. If a child is a text node
 * containing a work item string, change the string into text with an
 * embedded hyperlink. If a child is a non-link element, recursively
 * run this function on it.
 */
function markupWIs(node) {
	for (var i=0; i<node.childNodes.length; i++) {
		var child= node.childNodes[i];
		if (child.nodeType === TEXT_NODE && wiMatcher.test(child.nodeValue)) {
			
			// create a dummy span to simplify creating the new DOM nodes
			var dummy= document.createElement("span");
			dummy.innerHTML= child.nodeValue.replace(wiMatcher, wiReplacer);
			
			var parent= child.parentNode;
			while (dummy.firstChild) {
				parent.insertBefore(dummy.removeChild(dummy.firstChild), child);
			}
			
			parent.removeChild(child);

		} else if (child.nodeType === ELEMENT_NODE && child.tagName !== "A") {
			// otherwise if the current child node is an element but not a link,
			// recursively call this function on the element
			markupWIs(child);
		}
	}
}

})();